Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(822)

Unified Diff: chrome/browser/ui/cocoa/browser_window_cocoa.mm

Issue 2754383004: Rename WebsiteSettings code to PageInfo. (Closed)
Patch Set: Upload missing comment fix for WebSettingsUI -> PageInfoUI. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_cocoa.mm
diff --git a/chrome/browser/ui/cocoa/browser_window_cocoa.mm b/chrome/browser/ui/cocoa/browser_window_cocoa.mm
index da581d9f00197d30ca57376c3ad4d9c1a765e52e..2991e80ab6535094deb95aa54984a6c72c13f3b9 100644
--- a/chrome/browser/ui/cocoa/browser_window_cocoa.mm
+++ b/chrome/browser/ui/cocoa/browser_window_cocoa.mm
@@ -40,7 +40,7 @@
#include "chrome/browser/ui/cocoa/key_equivalent_constants.h"
#import "chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h"
#import "chrome/browser/ui/cocoa/nsmenuitem_additions.h"
-#import "chrome/browser/ui/cocoa/page_info/website_settings_bubble_controller.h"
+#import "chrome/browser/ui/cocoa/page_info/page_info_bubble_controller.h"
#import "chrome/browser/ui/cocoa/profiles/avatar_base_controller.h"
#include "chrome/browser/ui/cocoa/restart_browser.h"
#include "chrome/browser/ui/cocoa/status_bubble_mac.h"
@@ -436,7 +436,7 @@ bool BrowserWindowCocoa::IsFullscreen() const {
}
bool BrowserWindowCocoa::IsFullscreenBubbleVisible() const {
- return false; // Currently only called from toolkit-views website_settings.
+ return false; // Currently only called from toolkit-views page_info.
}
void BrowserWindowCocoa::MaybeShowNewBackShortcutBubble(bool forward) {
@@ -682,13 +682,13 @@ void BrowserWindowCocoa::UserChangedTheme() {
}
}
-void BrowserWindowCocoa::ShowWebsiteSettings(
+void BrowserWindowCocoa::ShowPageInfo(
Profile* profile,
content::WebContents* web_contents,
const GURL& virtual_url,
const security_state::SecurityInfo& security_info) {
- WebsiteSettingsUIBridge::Show(window(), profile, web_contents, virtual_url,
- security_info);
+ PageInfoUIBridge::Show(window(), profile, web_contents, virtual_url,
+ security_info);
}
void BrowserWindowCocoa::ShowAppMenu() {
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_cocoa.h ('k') | chrome/browser/ui/cocoa/location_bar/location_icon_decoration.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698